#######################################################################
# mailgen.pm
#
# These routines generate the GnuDIP E-mail.
#
# See COPYING for licensing information.
#
# Written by:
#
#   Creighton MacDonnell
#   http://macdonnell.ca/
#
#######################################################################

# Perl modules
use strict;

# global variables
use vars qw($pref $thiscgi $thishost);

# GnuDIP common subroutines
use gdiplib;

#######################################################################
# E-mail to complete self registration
#######################################################################
sub mail_self {
  my $username = shift;
  my $domain   = shift;
  my $password = shift;
  my $email    = shift;

  if (!$$pref{'SERVER_KEY'}) {
    $$pref{'SERVER_KEY'} = randomsalt();
    updateprefs($pref);
  }
  my $checkval = md5_base64(
    "$username.$domain.$password.$email.$$pref{'SERVER_KEY'}"
    );

  my $url =
    "$thiscgi?selfcreate=$username,$domain,$password," .
    uri_escape($email) . "," . uri_escape($checkval)
    ;

  my $from = 'GnuDIP@' . $thishost;

  my $ok = callsendmail(tst(qq*
To: $email
From: $from
Subject: GnuDIP Self Registration at $thishost

To complete self registration use this URL:

  $url
.
*));

  pg_error('config') if !$ok;
}

#######################################################################
# E-mail to complete E-mail change
#######################################################################
sub mail_newemail {
  my $username = shift;
  my $domain   = shift;
  my $password = shift;
  my $email    = shift;

  if (!$$pref{'SERVER_KEY'}) {
    $$pref{'SERVER_KEY'} = randomsalt();
    updateprefs($pref);
  }
  my $checkval = md5_base64(
    "$username.$domain.$password.$email.$$pref{'SERVER_KEY'}"
    );

  my $url =
    "$thiscgi?newemail=$username,$domain,$password," .
    uri_escape($email) . "," . uri_escape($checkval)
    ;

  my $from = 'GnuDIP@' . $thishost;

  my $ok = callsendmail(tst(qq*
To: $email
From: $from
Subject: GnuDIP E-mail Update at $thishost

To complete your E-mail address update use this URL:

  $url
.
*));

  pg_error('config') if !$ok;
}

#######################################################################
# E-mail with Quick Login URL
#######################################################################
sub mail_quick {
  my $username = shift;
  my $domain   = shift;
  my $password = shift;
  my $email    = shift;

  my $quick =
    "$thiscgi?login=enc&username=$username&password=$password";
  if ($domain ne '') {
    $quick .= "&domain=$domain";
  }

  my $from = 'GnuDIP@' . $thishost;

  my $ok = callsendmail(tst(qq*
To: $email
From: $from
Subject: GnuDIP Quick Login URL for $thishost

You may login to GnuDIP at $thishost using this Quick Login URL:

  $quick
.
*));

  pg_error('config') if !$ok;
}

#######################################################################
# must return 1
#######################################################################
1;

